import { useMemo, useEffect, useState } from "react";
import {
  EllipsisText,
  InternalLink,
  Table,
  SimpleAccordion,
  usePagination
} from "@ess-ics/ce-ui-common";
import { Typography, Stack } from "@mui/material";
import {
  getNoOfIOCs,
  getNoOfHosts,
  isDeploymentJob,
  calculateHostText
} from "./JobUtils";
import { JobRevisionChip } from "./JobRevisionChip";
import { ROWS_PER_PAGE } from "../../constants";

const columns = [
  {
    field: "ioc",
    headerName: "IOC",
    flex: 0.7
  },
  {
    field: "host",
    headerName: "Host",
    flex: 1
  }
];

const createRow = (job, action) => {
  return {
    id: `${job.host.hostId}${job.iocId}`,
    ioc: (
      <Stack
        sx={{ padding: "8px 16px 8px 0" }}
        gap={2}
      >
        <Stack
          key={job.iocId}
          flexDirection="row"
          gap={1}
        >
          <InternalLink
            to={`/iocs/${job.iocId}`}
            label={`Ioc details, ${job.iocName}`}
          >
            <EllipsisText>{job.iocName}</EllipsisText>
          </InternalLink>
          {isDeploymentJob(action) && (
            <JobRevisionChip
              gitReference={job.gitReference}
              gitProjectId={job.gitProjectId}
            />
          )}
        </Stack>
      </Stack>
    ),
    host: calculateHostText(job)
  };
};

export const JobDetailsBatchJob = ({ operation }) => {
  const [currentRows, setCurrentRows] = useState([]);
  const { pagination, setPagination } = usePagination({
    rowsPerPageOptions: ROWS_PER_PAGE,
    initLimit: ROWS_PER_PAGE[0],
    initPage: 0,
    initTotalCount: operation.jobs.length
  });

  const noOfIOCs = useMemo(() => {
    return getNoOfIOCs(operation.jobs);
  }, [operation]);

  const noOfHosts = useMemo(() => {
    return getNoOfHosts(operation.jobs);
  }, [operation]);

  useEffect(() => {
    const { limit, page } = pagination;
    const list = operation.jobs.reduce((acc, _, index) => {
      if (index % limit === 0) {
        acc.push(operation.jobs.slice(index, index + limit));
      }
      return acc;
    }, []);

    setCurrentRows(list[page]);
  }, [pagination, setPagination, operation]);

  return (
    <SimpleAccordion
      summary={
        <Stack
          flexDirection="row"
          alignItems="end"
          sx={{ width: "100%" }}
          gap={1}
        >
          {" "}
          <Typography
            component="h2"
            variant="h3"
          >
            Batch
          </Typography>
          <Typography
            variant="body2"
            sx={{ fontWeight: "600", marginRight: "10px" }}
          >
            {noOfIOCs} {noOfIOCs > 1 ? "IOCs" : "IOC"}
            {", "}
            {noOfHosts} {noOfHosts > 1 ? "Hosts" : "Host"}
          </Typography>
        </Stack>
      }
    >
      <Table
        columns={columns}
        disableColumnSorting
        rows={currentRows.map((job) => createRow(job, operation.action))}
        pagination={pagination}
        onPage={setPagination}
      />
    </SimpleAccordion>
  );
};
