import { EllipsisText, InternalLink } from "@ess-ics/ce-ui-common";
import { Typography } from "@mui/material";

export const ACTION_TYPES = {
  DEPLOY: "DEPLOY",
  UNDEPLOY: "UNDEPLOY",
  BATCH_DEPLOY: "BATCH_DEPLOY",
  BATCH_UNDEPLOY: "BATCH_UNDEPLOY",
  START: "START",
  STOP: "STOP"
};

export const isBatchJob = (action) =>
  action === ACTION_TYPES.BATCH_DEPLOY ||
  action === ACTION_TYPES.BATCH_UNDEPLOY;

export const isDeploymentJob = (action) =>
  action === ACTION_TYPES.BATCH_DEPLOY || action === ACTION_TYPES.DEPLOY;

export const getNoOfIOCs = (jobs) =>
  [...new Set(jobs.map((job) => job.iocId))].length;

export const getNoOfHosts = (jobs) =>
  [...new Set(jobs.map((job) => job.host.hostId))].length;

export const calculateHostText = (job) => {
  // host is resolvable => show link for users
  if (job?.host?.hostId && job?.host?.externalIdValid) {
    return (
      <InternalLink
        to={`/hosts/${job.host.hostId}`}
        label={`Host Details, ${job.host.fqdn}`}
        width="100%"
      >
        <EllipsisText>{job.host.fqdn}</EllipsisText>
      </InternalLink>
    );
  }
  // gray out hostname if it is from cache
  return (
    <Typography color="gray">
      <EllipsisText>{job?.host?.fqdn}</EllipsisText>
    </Typography>
  );
};
